@@ -13,7 +13,7 @@
 ##############################################################################
 """URL Namespace Implementations
 
-$Id: namespace.py 70897 2006-10-24 08:21:55Z flox $
+$Id: namespace.py 95522 2009-01-29 19:42:56Z ctheune $
 """
 __docformat__ = 'restructuredtext'
 
@@ -71,7 +71,7 @@ def namespaceLookup(ns, name, object, request=None):
       >>> namespaceLookup('fiz', 'bar', C())    # doctest: +ELLIPSIS
       Traceback (most recent call last):
       ...
-      TraversalError: (<zope.traversing.namespace.C object at 0x...>, '++fiz++bar')
+      LocationError: (<zope.traversing.namespace.C object at 0x...>, '++fiz++bar')
 
     We'll get the same thing if we provide a request:
 
@@ -80,7 +80,7 @@ def namespaceLookup(ns, name, object, request=None):
       >>> namespaceLookup('foo', 'bar', C(), request)    # doctest: +ELLIPSIS
       Traceback (most recent call last):
       ...
-      TraversalError: (<zope.traversing.namespace.C object at 0x...>, '++foo++bar')
+      LocationError: (<zope.traversing.namespace.C object at 0x...>, '++foo++bar')
 
     We need to provide a view:
 
@@ -236,7 +236,7 @@ class acquire(SimpleHandler):
           >>> adapter.traverse('d', ())
           Traceback (most recent call last):
           ...
-          TraversalError: (splat, 'd')
+          LocationError: (splat, 'd')
         """
         i = 0
         ob = self.context
@@ -307,14 +307,17 @@ class etc(SimpleHandler):
 
         ob = self.context
 
-        # TODO: lift dependency on zope.app
         if (name in ('process', 'ApplicationController')
             and IContainmentRoot.providedBy(ob)):
             # import the application controller here to avoid circular
             # import problems
-            from zope.app.applicationcontrol.applicationcontrol \
-                 import applicationController
-            return applicationController
+            try:
+                from zope.app.applicationcontrol.applicationcontrol \
+                     import applicationController
+            except ImportError:
+                pass
+            else:
+                return applicationController
 
         if name not in ('site',):
             raise TraversalError(ob, name)
@@ -381,6 +384,7 @@ class vh(view):
         traversal_stack = request.getTraversalStack()
         app_names = []
 
+        name = name.encode('utf8')
         if name:
             try:
                 proto, host, port = name.split(":")
